<?php
/**
 * @name common
 * @description fichier commun à toutes les pages web de l'application
 *		vérifie qu'un utilisateur est authentifié: objet $user est disponnible il contient les infos de l'utilisateur (droit d'accès etc)
 *		Initie la connexion à la base de donnée: objet PDO $dbconnection
 *		Instancie l'objet smarty: objet $smarty dispo
 *		Met en place le CSS et les variables de langue
 *		Initialise les élément commun à chaque page (menu,etc)
 * @author Nicolas Biersart <n.biersart@esia-network.com>
 * @contributor
 * @copyright Nicolas Biersart 2012
 * @license
 * @esia 1.00
 * @version 1.0.0
 * @date 15/04/2013
 */
$path = rtrim ($_SERVER['DOCUMENT_ROOT'],'/');
require_once $path.'/esia.conf.php';

//include $path.'/Model_adm.php';
require_once USR_CLASS;
include_once LIB_LOG;
include_once MVCMODEL;
include_once NAVBAR_CLASS;
require_once(SMARTY_DIR . 'Smarty.class.php');
include_once $path . '/libs/utils.lib.php';
if(is_dir('./install'))
{
	header('Location: ./install/index.php');
	exit(0);
}
//connection à la base de donnée
try
{
	$dbconnection = new PDO('pgsql:host='.DB_HOST.';port='.DB_PORT.';dbname='.DB_NAME, DB_USERNAME, DB_PWD);
	$dbconnection->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_WARNING);
}
catch(Exception $e)
{
	echo 'PDO SQL ERROR: '.$e->getMessage().'<br />';
	echo 'N° : '.$e->getCode();
}
session_start();
//initialisation de l'objet smarty
$smarty = new Smarty();
$smarty_plugins_dir = $path.'/libs/smarty-plugins';
foreach(scandir($smarty_plugins_dir) as $file)
{
	if( is_dir("$smarty_plugins_dir/$file") )
	{
		$smarty->addPluginsDir("$smarty_plugins_dir/$file");
	}
}
//$smarty->allow_php_tag=true;
$CONFIG = Model_esia::getConfiguration($dbconnection,NULL,TRUE);
$smarty->assign('banner_path',$CONFIG['DEFAULT_BANNER']['value']);
$smarty->assign('bannerFond',$CONFIG['DEFAULT_BANNER_FONTCOLOR']['value']);
date_default_timezone_set($CONFIG['DEFAULT_TIMEZONE']['value']);
//création de l'objet user & vérification si il est loggé ou pas
try
{
	$user = new User($dbconnection);
	$user->sessionIDisValid(Model_esia::getDuringSession($dbconnection));
	if(!empty($_SESSION['ldap_username']))
	{
		$user->setName($_SESSION['ldap_username']);
	}
	$smarty->assign('logged_user_name',$user->getName());
	$smarty->assign('logged_user_id',$user->getId());
	if(!isset($no_trace_uri)&& !empty($no_trace_uri)&&$no_trace_uri!=true)
	{
		if(isset($_SESSION['current_page']) && !empty($_SESSION['current_page']))
		{
			$_SESSION['previous_page']= $_SESSION['current_page'];
		}
		$_SESSION['current_page']= $_SERVER['REQUEST_URI'];
	}
	if(isset($_SESSION['dashboard_only']))
	{
		$authorized=false;
		foreach($_SESSION['dashboard_only'] as $reg)
		{
			//print_r($_SERVER['SCRIPT_NAME']);
			if(preg_match($reg,$_SERVER['SCRIPT_NAME']))
			{
				$authorized=true;
				break;
			}
		}
		if($authorized===false)
		{
			throw new UserException("Bad access");
		}
	}
}
catch(UserException $e)	//Il n'est pas connecté
{
	//echo $e->getMessage();
	//configuration de la langue de l'application
	include $path.'/lang/'.LANG.'/'.LANG.'.php';
	//configuration moteur template
	$theme = Model_esia::getApplicationTheme($dbconnection);
	$smarty->template_dir = $path.'/theme/'.$theme.'/template/';
	$smarty->compile_dir = $path.'/theme/'.$theme.'/templates_c/';
	$smarty->config_dir = $path.'/configs/';
	$smarty->cache_dir = $path.'/cache/';
	$smarty->assign('css', '/theme/'.$theme.'/design.css');

	$smarty->assign('title','Esia Network Management');
	$smarty->assign('lang', $lang);
	$smarty->assign('url', $_SERVER['REQUEST_URI']);
	$smarty->assign('l_login', $lang['LOGIN']);
	$smarty->assign('l_password', $lang['PASSWORD']);
	$smarty->assign('l_connection', $lang['CONNECTION']);
	$smarty->display('login.html');
	exit(0);
}
if(!empty($_SESSION['previous']))
{
	if(strpos($_SERVER['SCRIPT_NAME'],'administration.php')===FALSE)
	{
		unset($_SESSION['previous']);
	}
}
$th = 0;
//Mise en place des préférence de l'utilisateur (CSS)
if(isset($user) )
{
	if($user->getTheme()!="")
	{
		$th=1;
		$smarty->template_dir = $path.'/theme/'.$user->getTheme().'/template/';
		$smarty->compile_dir = $path.'/theme/'.$user->getTheme().'/templates_c/';
		$smarty->config_dir = $path.'/configs/';
		$smarty->cache_dir = $path.'/cache/';
		$smarty->assign('css', '/theme/'.$user->getTheme().'/design.css');
		include_once $path.'/theme/'.$user->getTheme().'/icons.php';
	}
}
if($th==0)
{
	//configuration moteur template
	$theme = Model_esia::getApplicationTheme($dbconnection);
	$smarty->template_dir = $path.'/theme/'.$theme.'/template/';
	$smarty->compile_dir = $path.'/theme/'.$theme.'/templates_c/';
	$smarty->config_dir = $path.'/configs/';
	$smarty->cache_dir = $path.'/cache/';
	$smarty->assign('css', '/theme/'.$theme.'/design.css');
	include_once $path.'/theme/'.$theme.'/icons.php';
}
//mise en place des fichier de langue
$langVarName = 'lang'; // Nom de la variable de langue principale (variable dynamique). On peut modifier ce nom de variable pour re-inclure les fichiers de langues dans une autre langue dans 2 variables différentes (langue de l'user et langue par defaut du site)
$lang_abre =LANG;
if($user->getLang()!="")
{
	//configuration de la langue de l'application
    $lang_abre = $user->getLang();
}
$lang_path = $path.'/lang/'.$lang_abre.'/';
if(file_exists($lang_path.$lang_abre.'.php'))
{
    include $path.'/lang/'.$lang_abre.'/'.$lang_abre.'.php';
}
if(file_exists($lang_path.'/common_plugin_name.php'))
{
    include $lang_path.'/common_plugin_name.php';
}
if(file_exists($lang_path.'/message.php'))
{
    include $lang_path.'/message.php';
}
if(file_exists($path.'/data/lang/'.$lang_abre.'.php'))
{
    include $path.'/data/lang/'.$lang_abre.'.php';
}
// Intégration des variables de langues des webp
$arr = Model_esia::getWebPlugin($dbconnection);
foreach($arr as $row)
{
    if(!empty($row['dir_lang']))
    {
		$lang_webp_path = $path . $row['apache_path'] . $row['dir_lang'];
		$lang_webp_file = $lang_abre . '.php';
		if(file_exists($lang_webp_path . $lang_webp_file) == TRUE)
		{
			include $lang_webp_path . $lang_webp_file;
		}
		else
		{
			$lang_webp_file = LANG . '.php';
			if(file_exists($lang_webp_path . $lang_webp_file) == TRUE)
			{
				include $lang_webp_path . $lang_webp_file;
			}
		}
    }
}
$smarty->assign('lang', $lang);
//
//gestion de la licence
//
$licence=array();
try
{
	$licence = Model_esia::getLicenceInformation($dbconnection);
}
catch(EsiaDbException $e)	//Il n'est pas connecté
{
	$mes = $e->getMessage();
	if($mes == 'Licence not found')
	{
		$licence['id'] = 'LITE';
		$licence['expire'] = time()+60*60*24*90;
		$licence['node'] = 50;
		$licence['type'] = 'LITE';
		if(file_exists(RACINE_SITE.'/data/lite-registered.lic'))
		{
			$data = file_get_contents(RACINE_SITE.'/data/lite-registered.lic');
			if($data == '4a55684d73f77039df4405208413e0a0')
			{
				$licence['type'] = 'LITE - REGISTERED';
			}
		}
	}
	else
	{
		$mes .= $lang['ERROR_LICENCE_OTHER'].'<br />';
		$reg = '<a href="/about.php?action=licence">'.$lang['ERROR_LICENCE_HERE'].'</a><br />';
		$mes =preg_replace('#\$HERE\$#',$reg,$mes);
		$smarty->assign('l_licence_err',  $mes);
	}
}
$smarty->assign('licence',  $licence);
//
// Initialisation terminée affichage des élément commun à toutes les pages
//
if(!isset($ESIA_WIDGET_NOTREE))
{
	include $path.'/inc/common_build_all.php';
	//Le démon esia est-il lancé ?
	$out = exec("ps -ae | grep 'esiaDaemon'");
	if($out=='')
	{
		$smarty->assign('l_daemon_err',  $lang['ERROR_ESIA_NOT_START']);
	}
	//Vérification variable système (si il faut redémarrer le démon ou pas
	$row =  Model_esia::getDaemonState($dbconnection);
	if($row=="2")
	{
		$smarty->assign('l_daemon_err',  $lang['ERROR_ESIA_MUST_RESTART']);
	}
}
//Barre de navigation
$navbar = new navbar($dbconnection, 'navbar',$lang['NODES'],'/node_index.php?nodegroup=:id', $ICONS['groupNode']);
$url = $smarty->getTemplateVars('url_home');
if(empty($url))
{
	$dashboards = Model_esia::getDashboards($dbconnection,'LANG_DASHBOARD_HOME_NEW',$user->getId());
	$dashboards = array_shift($dashboards);
	$navbar->addElement($lang['INDEX'], '/dashboard/default.php?id='.$dashboards['id'],$ICONS['home']);
}
else
{
	$navbar->addElement($lang['INDEX'], $url,$ICONS['home']);
}
$smarty->assign('title','Esia Network Management');

//VARIABLE DE LANGUE
$smarty->assign('lang_ini', LANG);
$smarty->assign('l_index', $lang['INDEX']);
$smarty->assign('l_search', $lang['SEARCH']);
$smarty->assign('l_logout', $lang['LOGOUT']);
$smarty->assign('l_node', $lang['NODE']);
$smarty->assign('l_account', $lang['ACCOUNT']);
$smarty->assign('l_about', $lang['ABOUT']);
$smarty->assign('l_dashboard', $lang['DASHBOARD']);
$smarty->assign('l_service_state', $lang['SERVICE_STATE']);
//vérification des droits d'accès au partie d'administration d'ESIA
if($user->getDroits($dbconnection,"esia_administration"))
{
	$smarty->assign('l_admin', $lang['ADMIN']);
}
if($user->getDroits($dbconnection,"esia_maintenance"))
{
	$smarty->assign('l_maintenance', $lang['MAINTENANCE']);
}
if($user->getDroits($dbconnection,"esia_device"))
{
    $smarty->assign('l_access_node_control', $lang['ADMIN']);
}
if($user->getDroits($dbconnection,"esia_users"))
{
	$smarty->assign('l_access_users_control', $lang['USERS']);
}
if($user->getDroits($dbconnection,"esia_groups"))
{
	$smarty->assign('l_access_groups_control', $lang['GROUPS']);
}

$smarty->assign('plan_admin_perm',$user->getDroits($dbconnection,"map_administration") == 1);
function cmptree($a, $b)
{
	return strcasecmp($a['name'],$b['name']);
}
?>
