#!/usr/bin/php
<?php

// Get parameters
$options = getopt('c:D');

if(!empty($options['c']))
{
	$_SERVER['DOCUMENT_ROOT'] = $options['c'];
}
else
{
	$_SERVER['DOCUMENT_ROOT'] = '/usr/local/esia/public_html/';
}
$configfile = $_SERVER['DOCUMENT_ROOT'] . '/esia.conf.php';
if(file_exists($configfile) === FALSE)
{
	echo "Configuration file does not exist ($configfile)\n";
	exit(1);
}

$DEBUG = FALSE;
if(isset($options['D']))
{
	$DEBUG = TRUE;
}

// Include esia conf & model
include_once $configfile;
include_once MVCMODEL;
include_once $_SERVER['DOCUMENT_ROOT'] . '/Model_adm.php';

try
{
	$date = new DateTime();
	echo $date->format('d-m-Y H:i:s') . "\n\n";
	echo "Connect to DB\n";
	try
	{
		$dbconnection = new PDO('pgsql:host=' . DB_HOST . ';port=' . DB_PORT . ';dbname=' . DB_NAME, DB_USERNAME, DB_PWD);
		$dbconnection->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_WARNING);
	}
	catch(Exception $e)
	{
		echo 'PDO SQL ERROR: ' . $e->getMessage() . '<br />';
		echo 'N° : ' . $e->getCode();
		exit(1);
	}
	Trace($DEBUG, "DB connexion is OK\n");

	$MAXDAY = Model_esia::getConfiguration($dbconnection, 'DEVICES_NOTES_PURGE');
	$MAXDAY = $MAXDAY['DEVICES_NOTES_PURGE']['value'];

	Trace($DEBUG, "Purging all devices notes older than $MAXDAY days\n");
	Model_adm::purgeDevicesNotesByDays($dbconnection, $MAXDAY, NULL, NULL, TRUE);
	echo "Purge is complete\n";
}
catch(EsiaDbException | Exception $e)
{
	echo "EXCEPTION: " . $e->getMessage() . "\n";
	exit(1);
}
exit(0);

function Trace($debug, $msg)
{
	if($debug)
	{
		if(is_array($msg))
		{
			print_r($msg);
		}
		else 
		{
			echo "DEBUG: $msg\n";
		}
	}
}
?>
