<?php
/**
 * Esia UI forms_select
 * @author Nicolas Biersart
 * @param array $params un tableau associatif contenant les paramètres passé à la fonction
 * 				'id' string identifiant JS
 *   			'name' string (optionnel) Nom HTML du select
 *     			'multiple' boolean si spécifié passe le select en multiple
 *     			'ajax' string URI spécifié l'URL pour charger le select en ajax avec du JSON. Voir setData sur le site https://slimselectjs.com
 *   			'firstValue' si spécifié indique la première valeur de l'option
 *   			'firstText' si spécifié indique le premièr texte de l'option
 *				'value' array tableau contenant les valeurs option du select. 2 formats peuvent être passé
 *							le premier est un tableau clé => valeur. la clé étant l'attribut value de l'option et la valeur l'attribut texte
 * 							la deuxieme est un tableau associatif avec les clés 'id' et les clé 'name'. id étant l'attribut value de l'option et name l'attribut texte
 *   			'class' string (optionnel) classe CSS du select
 *   			'style' string (optionnel) attribut style
 *   			'onchange' string (optionnel) fonction JS appelé lors d'un changement
 *   			'other' string (optionnel) permet de fixer d'autre attribut HTML
 * 				'label' string (optionnel) texte du label associé au select
 * 				'labelclass' string (optionnel) la classe CSS associé au label
 * 				'labelstyle' string (optionnel) attribut style du label
 *   			'onclick' string (optionnel) fonction JS appelé si on clique sur le label
 *   			'placeholder' string (optionnel) indique le texte du placeHolder
 *   			'disable' string (optionnel) indique le texte du placeHolder
 *   			'keepopen' string (optionnel) si présent et que c'est un select multiple, garde la liste de selection ouverte tant qu'on clique dedans
 * @param Smarty_Internal_Template $template template object
 * @return string   la sortie au format HTML.
 * @uses ui_forms_select
 */
function smarty_function_eui_forms_select($params, $template)
{
	$output='';
	if(array_key_exists('label',$params))
	{
		$output.='<label for="'.$params['id'].'"';
		if(array_key_exists('labelclass',$params))
		{
			$output.=' class="'.$params['labelclass'].'"';
		}
		if(array_key_exists('labelstyle',$params))
		{
			$output.=' style="'.$params['labelstyle'].'"';
		}
		if(array_key_exists('onclick',$params))
		{
			$output.=' onclick="'.$params['onclick'].'"';
		}
		$output.='>'.$params['label'].'</label>';
	}
	$isMultiple = FALSE;
	$ajax = FALSE;
	$request_type= 'GET';
	$js_fct=FALSE;
	$init = 1;
	$selected=array();
	$selectdata=array();
	if(isset($params['firstValue']))
	{
		$selectdata[]=array('text'=>$params['firstText'],'value'=>$params['firstValue']);
	}
	if(!empty($params['ajax']))
	{
		$ajax = $params['ajax'];
		if(isset($params['type']))
		{
			$request_type = $params['type'];
		}
	}
	elseif(!empty($params['jsLoadFunction']))
	{
		$init = 0;
		$ajax = TRUE;
		$js_fct = $params['jsLoadFunction'];
	}
	else
	{
		if(isset($params['value']))
		{
			$arraySelected=array();
			if(isset($params['selected']))
			{
				if(is_array($params['selected']))
				{
					$arraySelected = $params['selected'];
				}
				else
				{
					$arraySelected = array($params['selected']);
				}
			}

			foreach($params['value'] as $key => $value)
			{
				$opt_key = $key;
				$opt_value = $value;
				if(is_array($value) && array_key_exists('id',$value) && array_key_exists('name',$value))
				{
					$key = $opt_key = $value['id'];
					$opt_value = $value['name'];
				}
				$selectdata[]=array('text'=>$opt_value,'value'=>$opt_key);
				if(in_array($key, $arraySelected))
				{
						$selected[]=$key;
				}
			}
		}
	}

	//création de la balise select
	$output .= '<select';
	if(array_key_exists('name',$params))
	{
		$output.=' name="'.$params['name'].'"';
		if(preg_match('#\[\]$#',$params['name']))
		{
			$isMultiple = TRUE;
			$output.=' multiple="multiple"';
		}
	}
	if(array_key_exists('id',$params))
	{
		$output.=' id="'.$params['id'].'"';
	}
	if(array_key_exists('class',$params))
	{
		$output.=' class="'.$params['class'].'"';
	}
	if(array_key_exists('style', $params))
	{
		$output.=' style="'.$params['style'].'"';
	}
	if(array_key_exists('others',$params))
	{
		$output.=' '.$params['others'];
	}
	if(array_key_exists('disabled',$params))
	{
		$output.=' disabled="disabled"';
	}
	if(array_key_exists('onchange',$params))
	{
		$output.=' onchange="'.$params['onchange'].'"';
	}
	if(array_key_exists('init',$params))
	{
		$output.=' data-init="0"';
	}
	else
	{
		$output.=' data-init="'.$init.'"';
	}
	$output.='></select>';
	//on vérifie s'il y a des  option à ajouter au select
	/*if(isset($params['firstValue']))
	{
		$output.='<option value="'.$params['firstValue'].'" >'.$params['firstText'].'</option>';
	}*/
	//smarty_function_eui_forms_select
	$ssSettings = '';
	$ssEvents = '';
	if(isset($params['placeholder']))
	{
		$ssSettings .= ", placeholder: true, text: '" . $params['placeholder'] . "'";
	}
	if($isMultiple && isset($params['keepopen']))
	{
		$ssSettings .= ", allowDeselect: true";
		$ssEvents .=
		'afterOpen: () => {
			const ssInstance = eui_sselect["' . $params['id'] . '"];
			if(ssInstance.settings.isMultiple)
			{
				ssInstance.settings.alwaysOpen = true;
				$(document).on("click.ssKeepOpen", function(e) {
					// Click outside of the content
					if(!$(e.target).hasClass("ss-content"))
					{
						ssInstance.settings.alwaysOpen = false;
						$(document).off(".ssKeepOpen");
					}
				}).on("keyup.ssKeepOpen", function(e) {
					// Press escape key
					if(e.keyCode == 27)
					{
						ssInstance.settings.alwaysOpen = false;
						ssInstance.close();
						$(document).off(".ssKeepOpen");
					}
				});
			}
		},';
	}
	$ssSettings = ltrim($ssSettings, ',');
	$output.='<script type="text/javascript">
		if(!eui_sselect)
		{
			var eui_sselect = {};
		}
		eui_sselect["' . $params['id'] . '"] = new SlimSelect({
			select: "#' . $params['id'] . '",
			settings: { ' . $ssSettings . '},
			events: { ' . $ssEvents . ' },
		});';
    if($ajax  !== FALSE)
    {
    	if($js_fct !==FALSE)
    	{
    		$output.=" $js_fct ";
    	}
    	else
    	{
    		$output.="eui_forms.select('".$params['id']."','$ajax',".json_encode($params['selected']).",'$request_type');";
    	}
    }
	else
    {
	    if(!empty($selectdata))
	    {
		    $output.='eui_sselect["'.$params['id'].'"].setData('.json_encode($selectdata,true).');';
	    }
	    if(!empty($selected))
	    {
		    $output.='eui_sselect["'.$params['id'].'"].setSelected('.json_encode($selected).');';
	    }
    }
	$output.='</script>';
	return $output;
}

?>
