<?php
/**
 * Esia UI smarty_function_eui_forms_selectNodes
 * @author Nicolas Biersart
 * @param array $params un tableau associatif contenant les paramètres passé à la fonction
 * 				'id' string identifiant JS
 *   			'name' string (optionnel) Nom HTML du select
 *   			'firstValue' si spécifié indique la première valeur de l'option
 *   			'firstText' si spécifié indique le premièr texte de l'option
 *				'value' array tableau contenant les valeurs option du select. 2 formats peuvent être passé
 *							le premier est un tableau clé => valeur. la clé étant l'attribut value de l'option et la valeur l'attribut texte
 * 							la deuxieme est un tableau associatif avec les clés 'id' et les clé 'name'. id étant l'attribut value de l'option et name l'attribut texte
 *   			'class' string (optionnel) classe CSS du select
 *   			'style' string (optionnel) attribut style
 *   			'onchange' string (optionnel) fonction JS appelé lors d'un changement
 *   			'other' string (optionnel) permet de fixer d'autre attribut HTML
 * 				'label' string (optionnel) texte du label associé au select
 * 				'labelclass' string (optionnel) la classe CSS associé au label
 * 				'labelstyle' string (optionnel) attribut style du label
 *   			'onclick' string (optionnel) fonction JS appelé si on clique sur le label
 *   			'placeholder' string (optionnel) indique le texte du placeHolder
 *   			'keepopen' string (optionnel) si présent et que c'est un select multiple, garde la liste de selection ouverte tant qu'on clique dedans
 * @param Smarty_Internal_Template $template template object
 * @return string   la sortie au format HTML.
 * @uses ui_forms_select
 */
function smarty_function_eui_forms_selectServices($params, $template)
{
	$template->_checkPlugins(
		array(
			array(
				'function' => 'smarty_function_eui_forms_select',
				'file'     => RACINE_SITE . '/libs/smarty-plugins/esia/function.eui_forms_select.php'
			)
		)
		);
	
	$id = $params['id'];
	$name = $params['name'];
	//on séléectionne les label passé en paramètre ou alors le label de langue par défaut
	$label_group = "";
	if(array_key_exists('label_group',$params))
	{
		$label_group = $params['label_group'];
	}
	else
	{
		$lan = $template->getTemplateVars('lang');
		if(array_key_exists('DASHBOARD_SELECT_GROUP_NODE',$lan))
		{
			$label_group = $lan['DASHBOARD_SELECT_GROUP_NODE'];
		}
		else
		{
			$label_group = 'Not variable lang found';
		}
	}
	$label_node = "";
	if(array_key_exists('label_node',$params))
	{
		$label_node = $params['label_node'];
	}
	else
	{
		$lan = $template->getTemplateVars('lang');
		if(array_key_exists('DASHBOARD_SELECT_NODE',$lan))
		{
			$label_node = $lan['DASHBOARD_SELECT_NODE'];
		}
		else
		{
			$label_node = 'Not variable lang found';
		}
	}
	$l_service = "";
	if(array_key_exists('label_service',$params))
	{
		$l_service = $params['label_service'];
	}
	else
	{
		$lan = $template->getTemplateVars('lang');
		if(array_key_exists('SERVICES',$lan))
		{
			$l_service = $lan['SERVICES'];
		}
		else
		{
			$l_service = 'Not variable lang found';
		}
	}

	if(array_key_exists('keepopen', $params))
	{
		$grp_node['keepopen'] = $params['keepopen'];
		$node['keepopen'] = $params['keepopen'];
		$service['keepopen'] = $params['keepopen'];
	}
	
	$inputClass= 'class="'.$params['class'].'"';
	$selected = $params['selected'];
	$grp_node['id']='grp_node_'.$params['id'];
	if(preg_match('#\[\]$#',$params['name']))
	{
		$grp_node['name']='grp_node_'.$params['id'].'[]';
	}
	else
	{
		$grp_node['name']='grp_node_'.$params['id'];
	}
	$grp_node['label']=$label_group;
	$grp_node['type']='POST';
	$grp_node['jsLoadFunction']="eui_forms.loadGroupByService('".$grp_node['id']."',".json_encode( $selected,true).")";
	
	//$selected = $params['id'];
	$grp_node['onchange']="eui_forms.selectNodes('node_".$params['id']."','".$grp_node['id']."')";
	$output .= smarty_function_eui_forms_select($grp_node, $template);
	
	$node['type']='POST';
	$node['id']='node_'.$params['id'];
	$node['label']=$label_node;
	$node['name']= $params['name'];
	$node['init']=0;
	if(preg_match('#\[\]$#',$params['name']))
	{
		$node['name']='node_'.$params['name'].'[]';
	}
	else
	{
		$node['name']='node_'.$params['name'];
	}
	$node['disabled']=1;
	if(!empty($selected))
	{
		$node['jsLoadFunction']="eui_forms.loadNodeByService('".$node['id']."',".json_encode( $selected,true).")";
	}
	$node['onchange']="eui_forms.selectServices('".$params['id']."','".$node['id']."')";
	$output .= smarty_function_eui_forms_select($node, $template);
	
	$service['disabled']=1;
	$service['id']=$params['id'];
	$service['label']=$l_service;
	$service['name']= $params['name'];
	$service['init']=0;
	if(!empty($params['onchange']))
	{
		$service['onchange']=$params['onchange'];
	}
	
	if(!empty($selected))
	{
		$service['jsLoadFunction']="eui_forms.loadService('".$service['id']."',".json_encode( $selected,true).")";
	}
	$output .= smarty_function_eui_forms_select($service, $template);
	return $output;
}
?>
