<?php
/**
*** @name Esia UI smarty_function_eui_input_file_block
*** @author Quentin GEORGE
*** @brief Set a custom input type file element in block mode
*** @param array $params assoc array with function parameters:
******* $params['id'] (optional) html ID of the input[type="file"] (default: inputFileBlock-{random number})
******* $params['name'] (optional) name of the input[type="file"] for the <form> (default: name = id)
******* $params['accept'] (optional) html attribute accept of the input[type="file"] (file types)
******* $params['onclick'] (optional) JS function to call on validate button (or input submit) click
******* $params['validBtn'] (optional) validate button type (default: submit) ('no' => nothing, 'button' => <button>, 'submit' => input[type="submit"])
******* $params['txtLabel'] (optional) label text (title of the block) (default: $lang['UPLOAD_A_FILE'])
******* $params['txtPlaceholder'] (optional) file text when file selection is empty (then replaced by the file name) (default: $lang['NO_FILES_SELECTED'])
******* $params['txtSubmit'] (optional) validate button text (default: $lang['APPLY'])
*** @param Smarty_Internal_Template $template template object
*** @return string HTML output
*** @usage: <form>{eui_input_file_block id="selectFile" name="selectFile" txtLabel=$lang.UPLOAD_A_FILE}</form>
**/
function smarty_function_eui_input_file_block($params, $template)
{
	// Get all texts from params or from lang var
	$tplLang = $template->getTemplateVars('lang');

	$texts = array(
		'label' => '',
		'placeholder' => '',
		'submit' => '',
	);
	// Input label
	if(isset($params['txtLabel']))
	{
		$texts['label'] = $params['txtLabel'];
	}
	elseif(isset($tplLang['UPLOAD_A_FILE']))
	{
		$texts['label'] = $tplLang['UPLOAD_A_FILE'];
	}
	// Input placeholder if no files selected
	if(isset($params['txtPlaceholder']))
	{
		$texts['placeholder'] = $params['txtPlaceholder'];
	}
	elseif(isset($tplLang['NO_FILES_SELECTED']))
	{
		$texts['placeholder'] = $tplLang['NO_FILES_SELECTED'];
	}
	// Submit button
	if(isset($params['txtSubmit']))
	{
		$texts['submit'] = $params['txtSubmit'];
	}
	elseif(isset($tplLang['APPLY']))
	{
		$texts['submit'] = $tplLang['APPLY'];
	}

	// Get file parameters
	// File input id
	if(empty($params['id']))
	{
		$id = 'inputFileBlock-' . rand(0, 9999);
	}
	else
	{
		$id = $params['id'];
	}
	// File input name
	if(empty($params['name']))
	{
		$name = $id;
	}
	else
	{
		$name = $params['name'];
	}
	// File input accept types
	$acceptAttr = '';
	if(!empty($params['accept']))
	{
		$acceptAttr = ' accept="' . $params['accept'] . '"';
	}
	// Validate button click function
	$onClick = '';
	if(!empty($params['onclick']))
	{
		$onClick = ' onclick="' . $params['onclick'] . '"';
	}

	// Set validate button type
	if(!isset($params['validBtn']))
	{
		$params['validBtn'] = 'submit';
	}
	switch($params['validBtn']) {
		case 'no':
			$htmlSubmit = '';
			break;
		case 'button':
			$htmlSubmit = '<button class="btnOk inputFileBlock-submit" disabled="true"' . $onClick . '>' . $texts['submit'] . '</button>';
			break;
		case 'submit':
		default:
			// By default set the submit form input
			$htmlSubmit = '<input class="inputFileBlock-submit" type="submit" value="' . $texts['submit'] . '" disabled="true"' . $onClick . '>';
			break;
	}

	// Build html output
	$html  = '
	<div class="inputFileBlock">
		<label for="' . $id . '" class="inputFileBlock-select">
			<span class="inputFileBlock-label">' . $texts['label'] . '</span>
			<span class="inputFileBlock-filename">' . $texts['placeholder'] . '</span>
		</label>
		<input id="' . $id . '" class="inputFileBlock-input" type="file" name="' . $name . '"' . $acceptAttr . '>
		' . $htmlSubmit . '
	</div>';

	// Add script
	$html .= '
	<script type="text/javascript">
		$("#' . $id . '").on("change", function(e) {
			if($(this).val().length > 0)
			{
				const fileName = e.target.files[0].name;
				const block = $(this).closest(".inputFileBlock");
				block.addClass("active");
				$(".inputFileBlock-filename", block).html(fileName);
				$(".inputFileBlock-select", block).attr("title", fileName);
				$(".inputFileBlock-submit", block).attr("disabled", false);
			}
		});
	</script>';

	return $html;
}
?>
