<?php
/**
*** @name Esia UI smarty_function_eui_tables_selectRows
*** @author Quentin GEORGE
*** @brief Set table th or td with row check box selector
*** @param array $params assoc array with function parameters:
******* $params['type'] cell type (th or td)
******* $params['value'] (optional) checkbox attr data-value used to get the selected values
******* $params['onclick'] (optional) JS function to call on checkbox click
******* $params['cell_class'] (optional) additional classe to set on the th
******* $params['checkbox_class'] (optional) additional classe to set on the checkbox
******* $params['no_table_cell'] (optional) do not add the table cell wrapper (th or td) only the content inside (table sorter ajax)
******* $params['title'] (optional) custom title to replace the one given by $template
*** @param Smarty_Internal_Template $template template object
*** @return string HTML output
**/
function smarty_function_eui_tables_selectRows($params, $template)
{
	// Set default parameters
	$title = '';
	// Get cell type (th or td)
	if(isset($params['type']) && $params['type'] == 'th')
	{
		$type = 'th';
		$name = 'tableSelectedRowsAll';
		$cellClass = 'selectRows center sorter-false filter-false columnSelector-disable';
		$checkboxClass = 'selectRows-all';
		if(!empty($params['title']))
		{
			$title = $params['title'];
		}
		else
		{
			$lang = $template->getTemplateVars('lang');
			if(isset($lang['SELECT_ALL_TABLE_VISIBLE']))
			{
				$title = $lang['SELECT_ALL_TABLE_VISIBLE'];
			}
		}
	}
	else
	{
		$type = 'td';
		$name = 'tableSelectedRows[]';
		$cellClass = 'selectRows center';
		$checkboxClass = 'selectRows-single';
		if(!empty($params['title']))
		{
			$title = $params['title'];
		}
	}

	$optionalAttrs = '';

	// Set value
	if(isset($params['value']))
	{
		$name = 'tableSelectedRows[' . $params['value'] . ']';
		$optionalAttrs .= ' data-value="' . $params['value'] . '"';
	}

	// Get JS function
	if(isset($params['onclick']))
	{
		$optionalAttrs .= ' onclick="' . $params['onclick'] . '"';
	}

	// Get additional classes
	if(!empty($params['cell_class']))
	{
		$cellClass .= ' ' . $params['cell_class'];
	}
	if(!empty($params['checkbox_class']))
	{
		$checkboxClass .= ' ' . $params['checkbox_class'];
	}

	// Check if the table cell (th or td) must be displayed
	if(isset($params['no_table_cell']))
	{
		$isTableCell = FALSE;
	}
	else
	{
		$isTableCell = TRUE;
	}

	// Build html output
	$html = '';
	if($isTableCell)
	{
		$html .= '<' . $type . ' class="' . $cellClass . '">';
	}
	$html .= 		'<div class="selectRows-spacer"></div>';
	$html .= 		'<label title="' . $title . '">';
	$html .= 			'<input class="' . $checkboxClass . '" type="checkbox" name="' . $name . '"' . $optionalAttrs . '/>';
	$html .= 		'</label>';
	if($isTableCell)
	{
		$html .= '</' . $type . '>';
	}

	return $html;
}
?>
