<?php
/**
 * @name node_notes
 * @description script PHP appellé en AJAX, Affiche les notes du noeud
 * @author Quentin George <q.george@esia-sa.com>
 * @contributor
 * @copyright Quentin George 2023
 * @license
 * @esia 3.2.5
 * @version 1.0.0
 * @date 07/12/2023
 */
$path = $_SERVER['DOCUMENT_ROOT'];
include_once $path . 'common.php';
include_once DEVICE_CLASS;
include_once $path . '/libs/nodeNotes.lib.php';

$nodeId = NULL;
$action = '';
if(!empty($_REQUEST['action']))
{
	$action = $_REQUEST['action'];
}
// Check for actions which require a response in JSON format
$isJSON = FALSE;
if(stripos($_SERVER['HTTP_ACCEPT'], 'json'))
{
	$isJSON = TRUE;
}

// Checking for node note access level (0 = NONE, 1 = VIEW, 2 = ADM)
$noteAccessLevel = 0;
try
{
	if(empty($_GET['id']) || !is_numeric($_GET['id']))
	{
		throw new Exception('Node ID is missing.');
	}

	// Instance node
	$node = Model_esia::InstanceNode($dbconnection, $_GET['id']);
	$nodeId = $node->getId();
		
	// Get node access rights
	if($user->getDroits($dbconnection, 'device_view', $node->getName()) == 1)
	{
		if($user->getDroits($dbconnection, 'device_notes_administration', $node->getName()) == 1)
		{
			$noteAccessLevel = 2;
		}
		elseif($user->getDroits($dbconnection, 'device_notes_view', $node->getName()) == 1)
		{
			$noteAccessLevel = 1;
		}
	}
	else
	{
		throw new Exception('The user cannot acces this node.');
	}
}
catch(EsiaDbException | Exception $e)
{
	// If something is catched, the access is denied
	if($isJSON == TRUE)
	{
		header('HTTP/1.1 401 Unauthorized');
		echo $e->getMessage();
		exit(0);
	}
	else
	{
		$smarty->assign('no_header', TRUE);
		$smarty->display('no_access.html');
		exit(0);
	}
}

try
{
	if($action == 'list')
	{
		if($noteAccessLevel < 1)
		{
			// Must have VIEW access at least
			$smarty->assign('no_header', TRUE);
			$smarty->display('no_access.html');
			exit(0);
		}
		$threadList = Model_esia::getDeviceNotesThread($dbconnection, $nodeId);
		$smarty->assign('threadList', $threadList);

		// Notes list are fetched in AJAX
	}
	elseif($action == 'listDetails')
	{
		if($noteAccessLevel < 1)
		{
			// Must have VIEW access at least
			$smarty->assign('no_header', TRUE);
			$smarty->display('no_access.html');
			exit(0);
		}

		// Handeled in ajax ts - display_ts_device.php (action == 'listDeviceNotes')
	}
	elseif($action == 'listThreads')
	{
		if($noteAccessLevel < 1)
		{
			// Must have VIEW access at least
			$smarty->assign('no_header', TRUE);
			$smarty->display('no_access.html');
			exit(0);
		}
		$threadList = Model_esia::getDeviceNotesThread($dbconnection, $nodeId);
		$smarty->assign('threadList', $threadList);

		// Get lang trad for all thread types
		$typesLang = array();
		foreach(Model_esia::DEVICE_NOTES_THREAD_TYPES as $type)
		{
			$langKey = 'NODE_NOTE_THREAD_TYPE_' . $type;
			if(isset($lang[$langKey]))
			{
				$typesLang[$type] = $lang[$langKey];
			}
			else
			{
				$typesLang[$type] = $type;
			}
		}
		$smarty->assign('typesLang', $typesLang);
	}
	elseif($action == 'addThread' || $action == 'updateThread')
	{
		$threadId = 0;
		if(isset($_REQUEST['threadId']))
		{
			$threadId = $_REQUEST['threadId'];
		}

		if(isset($_POST['confirmId']) && $_POST['confirmId'] == $nodeId)
		{
			/*
			** Validation form sended
			*/
			if($noteAccessLevel < 2)
			{
				// Must have ADM access
				throw new Exception($lang['BAD_ACCES']);
			}
			if(empty($_POST['thread_subject']))
			{
				throw new Exception('Thread subject is missing.');
			}
			$subject = trim($_POST['thread_subject']);
			
			if($action == 'updateThread')
			{
				// Update
				Model_esia::updateDeviceNotesThreadTitle($dbconnection, $nodeId, $threadId, $subject);
				$smarty->assign('success', $lang['NODE_NOTE_UPDATE_SUBJECT_SUCCESS']);
			}
			else
			{
				// Add
				$threadId = Model_esia::addDeviceNotesThread($dbconnection, $nodeId, $subject, 'TEXT');
				$smarty->assign('success', $lang['NODE_NOTE_ADD_SUBJECT_SUCCESS']);
				$action = 'updateThread';
			}
		}
		/*
		** Display html content
		*/
		if($noteAccessLevel < 2)
		{
			// Must have ADM access
			$smarty->assign('no_header', 'iframe');
			$smarty->assign('isDialog', TRUE);
			$smarty->display('no_access.html');
			exit(0);
		}

		$thread = array();
		if($action == 'updateThread')
		{
			if(empty($threadId))
			{
				throw new Exception('Thread ID is missing.');
			}
			// Get thread
			$thread = Model_esia::getDeviceNotesThread($dbconnection, $nodeId, $threadId)[0];
		}
		$smarty->assign('newThreadId', $threadId);
		$smarty->assign('thread', $thread);
	}
	elseif($action == 'deleteThread')
	{
		$threadId = 0;
		if(isset($_REQUEST['threadId']))
		{
			$threadId = $_REQUEST['threadId'];
		}
		else
		{
			throw new Exception('Thread ID is missing.');
		}

		if(isset($_POST['confirmId']) && $_POST['confirmId'] == $nodeId)
		{
			/*
			** Validation form sended
			*/
			if($noteAccessLevel < 2)
			{
				// Must have ADM access
				throw new Exception($lang['BAD_ACCES']);
			}

			Model_esia::deleteDeviceNotesThread($dbconnection, $threadId, $nodeId);
			$smarty->assign('success', $lang['NODE_NOTE_SUBJECT_DELETE_MSG_SUCCESS']);
		}
		else
		{
			/*
			** Display html content
			*/
			if($noteAccessLevel < 2)
			{
				// Must have ADM access
				$smarty->assign('no_header', 'iframe');
				$smarty->assign('isDialog', TRUE);
				$smarty->display('no_access.html');
				exit(0);
			}

			// Get thread data
			$thread = Model_esia::getDeviceNotesThread($dbconnection, $nodeId, $threadId)[0];
			$smarty->assign('thread', $thread);
		}
	}
	elseif($action == 'addNote' || $action == 'updateNote')
	{
		$noteId = 0;
		if(isset($_REQUEST['noteId']))
		{
			$noteId = $_REQUEST['noteId'];
		}

		if(isset($_POST['confirmId']) && $_POST['confirmId'] == $nodeId)
		{
			/*
			** Validation form sended
			*/
			if($noteAccessLevel < 2)
			{
				// Must have ADM access
				throw new Exception($lang['BAD_ACCES']);
			}
			if(empty($_POST['note']))
			{
				throw new Exception('Note text is missing.');
			}
			// Clean text
			$message = trim($_POST['note']);
			$message = strip_tags($message);
			$message = htmlspecialchars($message);
			// If the user ask for no purge, set auto purge parameter to FALSE
			$autoPurge = TRUE;
			if(!empty($_POST['noPurge']))
			{
				$autoPurge = FALSE;
			}
			
			if($action == 'updateNote')
			{
				// Update
				if(empty($noteId))
				{
					throw new Exception('Note ID is missing.');
				}
				Model_esia::updateDeviceNotesMessage($dbconnection, $nodeId, $noteId, $message);
				// Update note auto purge
				if(!empty($_POST['noPurgeChange']))
				{
					Model_esia::updateDeviceNotesAutoPurge($dbconnection, $nodeId, $noteId, $autoPurge);
				}
				$smarty->assign('success', $lang['NODE_NOTE_UPDATE_MSG_SUCCESS']);
			}
			else
			{
				// Add
				if(empty($_POST['thread']))
				{
					throw new Exception('Note thread ID is missing.');
				}
				$noteId = Model_esia::addDeviceNote($dbconnection, $_POST['thread'], $user->getId(), $user->getName(), $message, NULL, $autoPurge);
				$smarty->assign('success', $lang['NODE_NOTE_ADD_MSG_SUCCESS']);
				$action = 'updateNote';
			}
		}
		/*
		** Display html content
		*/
		if($noteAccessLevel < 2)
		{
			// Must have ADM access
			$smarty->assign('no_header', 'iframe');
			$smarty->assign('isDialog', TRUE);
			$smarty->display('no_access.html');
			exit(0);
		}

		$thread = array();
		if($action == 'updateNote')
		{
			if(empty($noteId))
			{
				throw new Exception('Note ID is missing.');
			}
			// Get note
			$note = Model_esia::getDeviceNotes($dbconnection, $nodeId, $noteId, NULL, NULL, NULL, FALSE)[0];
			$smarty->assign('note', $note);
			// No purge selected or not
			if(isset($note['note_auto_purge']) && $note['note_auto_purge'] == FALSE)
			{
				$smarty->assign('noPurge', TRUE);
			}
			else
			{
				$smarty->assign('noPurge', FALSE);
			}
		}
		else
		{
			// Add
			// Get thread list
			$threads = Model_esia::getDeviceNotesThread($dbconnection, $nodeId);
			$smarty->assign('threads', $threads);
		}
	}
	elseif($action == 'deleteNote')
	{
		$noteId = 0;
		if(isset($_REQUEST['noteId']))
		{
			$noteId = $_REQUEST['noteId'];
		}
		else
		{
			throw new Exception('Note ID is missing.');
		}

		if(isset($_POST['confirmId']) && $_POST['confirmId'] == $nodeId)
		{
			/*
			** Validation form sended
			*/
			if($noteAccessLevel < 2)
			{
				// Must have ADM access
				throw new Exception($lang['BAD_ACCES']);
			}

			Model_esia::deleteDeviceNote($dbconnection, $noteId, $nodeId);
			$smarty->assign('success', $lang['NODE_NOTE_DELETE_MSG_SUCCESS']);
		}
		else
		{
			/*
			** Display html content
			*/
			if($noteAccessLevel < 2)
			{
				// Must have ADM access
				$smarty->assign('no_header', 'iframe');
				$smarty->assign('isDialog', TRUE);
				$smarty->display('no_access.html');
				exit(0);
			}

			// Get note data
			$note = Model_esia::getDeviceNotes($dbconnection, $nodeId, $noteId, NULL, NULL, NULL, FALSE)[0];
			$smarty->assign('note', $note);
		}
	}
	elseif($action == 'getThreadList')
	{
		if($noteAccessLevel < 1)
		{
			// Must have VIEW access
			throw new Exception($lang['BAD_ACCES']);
		}
		$threads = Model_esia::getDeviceNotesThread($dbconnection, $nodeId);

		echo json_encode($threads);
		exit(0);
	}
	elseif($action == 'setErrorHappenNote')
	{
		$addSysNoteErrors = NodeNotes\setErrorHappenNote($lang, $user, $dbconnection, $nodeId, $_POST['type'], $_POST['happenErrors']);

		if(empty($addSysNoteErrors))
		{
			echo json_encode(array('success' => true));
		}
		else
		{
			echo json_encode(array('error' => $addSysNoteErrors));
		}
		exit(0);
	}
	elseif($action == 'getDeviceNotes')
	{
		$isJSON = TRUE; // AJAX request returning html with smarty but if an error occure it must be a jqXHR.responseText
		if($noteAccessLevel < 1)
		{
			// Must have VIEW access
			throw new Exception($lang['BAD_ACCES']);
		}
		$smarty->assign('no_header', TRUE); // To return only html included in the condition (action == getDeviceNotes) whitout headings

		// Display an add note button if there is not notes
		if(isset($_GET['onEmptyAddNoteBtn']) && $_GET['onEmptyAddNoteBtn'] == TRUE)
		{
			$smarty->assign('onEmptyAddNoteBtn', TRUE);
		}

		$options = array(
			'noteId' => NULL,
			'threadId' => NULL,
			'limit' => NULL,
			'page' => NULL,
			'setMsgHtmlLink' => FALSE,
		);
		
		if(isset($_GET['noteId']))
		{
			$options['noteId'] = $_GET['noteId'];
		}
		if(isset($_GET['threadId']))
		{
			$options['threadId'] = $_GET['threadId'];
		}
		if(isset($_GET['limit']))
		{
			$options['limit'] = $_GET['limit'];
		}
		if(isset($_GET['page']))
		{
			$options['page'] = $_GET['page'];
		}
		if(isset($_GET['setMsgHtmlLink']) && $_GET['setMsgHtmlLink'] == TRUE)
		{
			$options['setMsgHtmlLink'] = TRUE;
		}

		$notesList = Model_esia::getDeviceNotes($dbconnection, $nodeId, $options['noteId'], $options['threadId'], $options['limit'], $options['page'], $options['setMsgHtmlLink']);

		$smarty->assign('notesList', $notesList);

		// Set the total notes count
		$totalCount = 0;
		if(isset($notesList[0]['total_count']))
		{
			$totalCount = $notesList[0]['total_count'];
		}
		$smarty->assign('totalCount', $totalCount);
	}
}
catch(EsiaDbException | Exception $e)
{
	if($isJSON == TRUE)
	{
		// For AJAX failed request
		header('HTTP/1.1 500 Internal Server Error');
		echo $e->getMessage();
		exit(0);
	}
	else
	{
		$smarty->assign('error', $e->getMessage());
	}
}

$smarty->assign('action', $action);
$smarty->assign('nodeId', $nodeId);
$smarty->assign('nodeName', $node->getName());
$smarty->assign('noteAccessLevel', $noteAccessLevel);

$smarty->display('node_notes.html');

?>
